@@ -707,6 +707,9 @@ void on_stackstore_row_inserted(GtkTreeModel *model, GtkTreePath *path, GtkTreeI
 void on_stackstore_row_deleted(GtkTreeModel *model, GtkTreePath *path, gpointer user_data);
 
 void on_historyview_selection_changed(GtkTreeSelection *select, gpointer);
+void on_historyview_item_edited(GtkCellRendererText*, gchar*, gchar*, gpointer);
+void on_historyview_item_editing_started(GtkCellRenderer*, GtkCellEditable*, gchar*, gpointer);
+void on_historyview_item_editing_canceled(GtkCellRenderer*, gpointer);
 
 void on_unit_edit_entry_name_changed(GtkEditable *editable, gpointer user_data);
 void on_unit_edit_combobox_class_changed(GtkComboBox *om, gpointer user_data);
@@ -754,6 +757,7 @@ void on_dataset_edit_button_new_property_clicked(GtkButton *button, gpointer use
 void on_dataset_edit_button_edit_property_clicked(GtkButton *button, gpointer user_data);
 void on_dataset_edit_button_del_property_clicked(GtkButton *button, gpointer user_data);
 void on_dataset_edit_button_names_clicked(GtkWidget *button, gpointer user_data);
+void on_dataproperty_edit_combobox_type_changed(GtkComboBox *om, gpointer);
 
 void on_datasets_button_newset_clicked(GtkButton *button, gpointer user_data);
 void on_datasets_button_editset_clicked(GtkButton *button, gpointer user_data);
