@@ -39,8 +39,6 @@
 
 enum {
 	UNITS_TITLE_COLUMN,
-	UNITS_NAMES_COLUMN,
-	UNITS_BASE_COLUMN,
 	UNITS_POINTER_COLUMN,
 	UNITS_FLAG_COLUMN,
 	UNITS_VISIBLE_COLUMN,
